@@ -8,7 +8,7 @@ import json
 def get_query_param(req: Request, key):
     param = req.args.get(key)
     if param is None:
-        raise Exception('param none')
+        raise Exception(f'key: %s error!' % key)
     return param
 
 
