@@ -120,7 +120,7 @@ class ReadConfig:
         if filepath:
             config_path = filepath
         else:
-            root_dir = os.path.dirname(os.path.abspath('.'))
+            root_dir = os.path.abspath('.')
             config_path = os.path.join(root_dir, "config.ini")
         self.cf = configparser.ConfigParser()
         self.cf.read(config_path)
@@ -134,3 +134,4 @@ class ReadConfig:
 def get_local_config(key: str, param: str):
     read_config = ReadConfig()
     return read_config.get_config(key, param)
+
